@@ -6,11 +6,9 @@ logger = logging.getLogger(__name__)
 
 # Create handlers
 handler = logging.StreamHandler(sys.stdout)
-handler.setLevel(logging.INFO)
 
 # Create formatters and add it to handlers
-format = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
-handler.setFormatter(format)
+handler.setFormatter(logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s'))
 
 # Add handlers to the logger
 logger.addHandler(handler)
